import { SwfServiceCatalogService } from "@kie-tools/serverless-workflow-service-catalog/dist/api";
import { TextDocument } from "vscode-languageserver-textdocument";
import { CodeLens, CompletionItem, Diagnostic, Position, Range } from "vscode-languageserver-types";
import { FileLanguage } from "../api";
import { CodeCompletionStrategy, SwfJsonPath, SwfLsNode } from "./types";
export declare type SwfLanguageServiceConfig = {
    shouldConfigureServiceRegistries: () => boolean;
    shouldServiceRegistriesLogIn: () => boolean;
    canRefreshServices: () => boolean;
    getSpecsDirPosixPaths: (textDocument: TextDocument) => Promise<{
        specsDirRelativePosixPath: string;
        specsDirAbsolutePosixPath: string;
    }>;
    shouldDisplayServiceRegistriesIntegration: () => Promise<boolean>;
    shouldReferenceServiceRegistryFunctionsWithUrls: () => Promise<boolean>;
    shouldIncludeJsonSchemaDiagnostics: () => Promise<boolean>;
};
export declare type SwfLanguageServiceArgs = {
    fs: {};
    lang: {
        fileLanguage: FileLanguage;
        fileMatch: string[];
    };
    serviceCatalog: {
        global: {
            getServices: () => Promise<SwfServiceCatalogService[]>;
        };
        relative: {
            getServices: (textDocument: TextDocument) => Promise<SwfServiceCatalogService[]>;
        };
        getServiceFileNameFromSwfServiceCatalogServiceId: (registryName: string, swfServiceCatalogServiceId: string) => Promise<string>;
    };
    config: SwfLanguageServiceConfig;
};
export declare class SwfLanguageService {
    private readonly args;
    constructor(args: SwfLanguageServiceArgs);
    getCompletionItems(args: {
        content: string;
        uri: string;
        cursorPosition: Position;
        cursorWordRange: Range;
        rootNode: SwfLsNode | undefined;
        codeCompletionStrategy: CodeCompletionStrategy;
    }): Promise<CompletionItem[]>;
    getDiagnostics(args: {
        content: string;
        uriPath: string;
        rootNode: SwfLsNode | undefined;
        getSchemaDiagnostics: (textDocument: TextDocument, fileMatch: string[]) => Promise<Diagnostic[]>;
    }): Promise<Diagnostic[]>;
    getCodeLenses(args: {
        content: string;
        uri: string;
        rootNode: SwfLsNode | undefined;
        codeCompletionStrategy: CodeCompletionStrategy;
    }): Promise<CodeLens[]>;
    dispose(): void;
    private getSwfCompletionItemServiceCatalogFunctionOperation;
}
export declare function findNodeAtLocation(root: SwfLsNode, path: SwfJsonPath): SwfLsNode | undefined;
export declare function findNodeAtOffset(root: SwfLsNode, offset: number, includeRightBound?: boolean): SwfLsNode | undefined;
export declare function getNodePath(node: SwfLsNode): SwfJsonPath;
export declare const positions_equals: (a: Position | null, b: Position | null) => boolean;
//# sourceMappingURL=SwfLanguageService.d.ts.map