import { Position, TextDocument } from "vscode-languageserver-textdocument";
import { CompletionItemKind, Range } from "vscode-languageserver-types";
import { SwfLanguageServiceCommandTypes } from "../api";
export declare type SwfJsonPath = (string | number)[];
export declare type SwfLsNodeType = "object" | "array" | "property" | "string" | "number" | "boolean" | "null";
declare type OmitDistributive<T, K extends PropertyKey> = T extends any ? T extends object ? Id<OmitRecursively<T, K>> : T : never;
declare type Id<T> = {} & {
    [P in keyof T]: T[P];
};
export declare type OmitRecursively<T extends any, K extends PropertyKey> = Omit<{
    [P in keyof T]: OmitDistributive<T[P], K>;
}, K>;
export declare type SwfLsNode = {
    type: SwfLsNodeType;
    value?: any;
    offset: number;
    length: number;
    colonOffset?: number;
    parent?: SwfLsNode;
    children?: SwfLsNode[];
};
export interface ShouldCompleteArgs {
    content: string;
    cursorOffset: number;
    cursorPosition: Position;
    node: SwfLsNode | undefined;
    path: SwfJsonPath;
    root: SwfLsNode | undefined;
}
export interface ShouldCreateCodelensArgs {
    content: string;
    node: SwfLsNode;
    commandName: SwfLanguageServiceCommandTypes;
}
export interface TranslateArgs {
    completion: object | string;
    completionItemKind: CompletionItemKind;
    currentNodeRange?: Range;
    cursorOffset: number;
    document: TextDocument;
    overwriteRange?: Range;
}
export interface CodeCompletionStrategy {
    translate(args: TranslateArgs): string;
    formatLabel(label: string, completionItemKind: CompletionItemKind): string;
    shouldComplete(args: ShouldCompleteArgs): boolean;
    getStartNodeValuePosition(document: TextDocument, node: SwfLsNode): Position | undefined;
    shouldCreateCodelens(args: ShouldCreateCodelensArgs): boolean;
}
export {};
//# sourceMappingURL=types.d.ts.map